@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2020 Vanessa Sochat.
+# Copyright (C) 2019-2022 Vanessa Sochat.
 
 # This Source Code Form is subject to the terms of the
 # Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
@@ -18,7 +18,9 @@ class hashVerifier(Struct):
         self.digest = digest
 
     def write(self, content):
-        """add bytes of content to the hash object"""
+        """
+        Add bytes of content to the hash object
+        """
         if not isinstance(content, bytes):
             content = bytes(content, "utf-8")
         self.hash.update(content)
@@ -26,7 +28,9 @@ class hashVerifier(Struct):
         self.digest.validate()
 
     def verified(self):
-        """calculate the hex digest against the digest"""
+        """
+        Calculate the hex digest against the digest
+        """
         return self.digest == NewDigest(self.digest.algorithm, self.hash)
 
 
